@@ -41,6 +41,7 @@
 ##' @param value initial set of objective observations \eqn{fn(par)}. Computed if not provided.
 ##' Not that \code{value} may NOT contain any \code{cheapfn} value,
 ##' @param control an optional list of control parameters. See "Details",
+##' @param ncores number of CPU available (> 1 makes mean parallel \code{TRUE}). Only used with \code{discrete} optimization for now.
 ##' @param ... additional parameters to be given to the objective \code{fn}.
 ##' @export
 ##' @return
@@ -153,8 +154,8 @@
 ##' points(res$par, col="blue", pch = 17)
 ##' }
 
-easyGParetoptim <- function (fn, cheapfn = NULL, budget, lower, upper, par=NULL, value=NULL, noise.var=NULL,
-                             control=list(method="SMS", trace=1, inneroptim="pso", maxit=100, seed=42), ...) {
+easyGParetoptim <- function (fn, ..., cheapfn = NULL, budget, lower, upper, par=NULL, value=NULL, noise.var=NULL,
+                             control=list(method="SMS", trace=1, inneroptim="pso", maxit=100, seed=42), ncores = 1) {
   
   if (is.null(control$method)) control$method <- "SMS"
   if (is.null(control$trace)) control$trace   <- 1
@@ -245,6 +246,7 @@ easyGParetoptim <- function (fn, cheapfn = NULL, budget, lower, upper, par=NULL,
     candidate.points <- matrix(rep(lower,control$maxit)+rep(upper-lower,control$maxit)*runif(control$maxit*d),byrow=T,ncol=d)
     optimcontrol = list(method="discrete", candidate.points=candidate.points, notrace = !control$trace>0)
   }
+  if (control$inneroptim=="discrete") optimcontrol <- list(method = "discrete", candidate.points = control$candidate.points)
   
   if (control$method=="SUR") {
     critcontrol$distrib <- "SUR"
@@ -259,11 +261,11 @@ easyGParetoptim <- function (fn, cheapfn = NULL, budget, lower, upper, par=NULL,
   if (is.null(noise.var)) {
     omEGO <- GParetoptim(model = model, fn = fn, cheapfn = cheapfn,
                          crit = control$method, nsteps=n.ite, lower=lower, upper=upper, cov.reestim=TRUE, 
-                         optimcontrol=optimcontrol, critcontrol = critcontrol, ...)
+                         optimcontrol=optimcontrol, critcontrol = critcontrol, ncores = ncores, ...)
   } else {
     omEGO <- GParetoptim(model = model, fn = fn, cheapfn = cheapfn, noise.var=noise.var, reinterpolation = TRUE, 
                          crit = control$method, nsteps=n.ite, lower=lower, upper=upper, cov.reestim=TRUE, 
-                         optimcontrol=optimcontrol, critcontrol = critcontrol, ...)
+                         optimcontrol=optimcontrol, critcontrol = critcontrol, ncores = ncores, ...)
   }
   
   allX <- omEGO$lastmodel[[1]]@X
